@@ -110,7 +110,6 @@ class LayerNode:
         self.variable_input_operands: list = [op for op in self.input_operands if op not in self.constant_operands]
         # Save the way an operand's tensor should be reshaped for interaction with other nodes.
         self.operand_tensor_reshape: Dict[str, list] = layer_attrs.get('operand_tensor_reshape',  {op: [] for op in self.operand_list})
-        
 
         ''' Step3: extract layer info, e.g. total operand size, total operand data reuse, total MAC operation, etc. '''
         self.extract_layer_info()
@@ -170,8 +169,11 @@ class LayerNode:
             # Clip this to the largest possible size for this partially relevant dimension (computed at initialization based on padding)
             pr_dim_size = min(self.pr_loop_dim_size[dim], pr_dim_size)
             return pr_dim_size
+        elif dim in self.loop_dim_size:
+            assert self.loop_dim_size[dim] == 1, "This line should only be reached when the dim has a size of 1 in the layer."
+            return 1
         else:
-            assert False
+            raise ValueError("Something went wrong in the initialization of the layer, or in the caller function.")
 
     def calc_tensor_dims(self, layer_op, loop_sizes):
         out = {}
